@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::CompileTests;
 {
-  $Dist::Zilla::Plugin::CompileTests::VERSION = '2.010';
+  $Dist::Zilla::Plugin::CompileTests::VERSION = '2.011';
 }
 # ABSTRACT: (DEPRECATED) common tests to check syntax of your modules
 
@@ -35,7 +35,9 @@ __END__
 
 =encoding utf-8
 
-=for :stopwords Jerome Quelin
+=for :stopwords Jerome Quelin Ahmad Luehrs Karen Etheridge Kent Fredric Marcel Gruenauer
+Olivier Mengu Randy M. Stauner Ricardo SIGNES fayland Zawawi Chris Weyl
+Harley Pig Jesse
 
 =head1 NAME
 
@@ -43,7 +45,7 @@ Dist::Zilla::Plugin::CompileTests - (DEPRECATED) common tests to check syntax of
 
 =head1 VERSION
 
-version 2.010
+version 2.011
 
 =head1 SYNOPSIS
 
